@@ -284,32 +284,36 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     // load the fpga image
     ////////////////////////////////////////////////////////////////////
     if (_xport_path == AXI) {
-        if (not device_addr.has_key("no_reload_fpga")) {
+        _do_not_reload = device_addr.has_key("no_reload_fpga");
+        if (not _do_not_reload) {
             // Load FPGA image if provided via args
-            if (device_addr.has_key("fpga")) {
-                common::load_fpga_image(device_addr["fpga"]);
-            // Else load the FPGA image based on the product ID
-            } else {
-                //extract the FPGA path for the e300
-                const boost::uint16_t pid = boost::lexical_cast<boost::uint16_t>(
+            const boost::uint16_t pid = boost::lexical_cast<boost::uint16_t>(
                     device_addr["product"]);
-                std::string fpga_image;
-                switch(e300_eeprom_manager::get_mb_type(pid)) {
-                case e300_eeprom_manager::USRP_E310_MB:
-                    fpga_image = find_image_path(E310_FPGA_FILE_NAME);
-                    break;
-                case e300_eeprom_manager::USRP_E300_MB:
-                    fpga_image = find_image_path(E300_FPGA_FILE_NAME);
-                    break;
-                case e300_eeprom_manager::UNKNOWN:
-                default:
-                    UHD_MSG(warning) << "Unknown motherboard type, loading e300 image."
+
+            std::string fpga_image;
+
+            //extract the FPGA path for the e300
+            switch(e300_eeprom_manager::get_mb_type(pid)) {
+            case e300_eeprom_manager::USRP_E310_MB:
+                fpga_image = device_addr.cast<std::string>("fpga",
+                    find_image_path(E310_FPGA_FILE_NAME));
+                _idle_image = find_image_path(E310_FPGA_IDLE_FILE_NAME);
+                break;
+            case e300_eeprom_manager::USRP_E300_MB:
+                fpga_image = device_addr.cast<std::string>("fpga",
+                    find_image_path(E300_FPGA_FILE_NAME));
+                _idle_image = find_image_path(E300_FPGA_IDLE_FILE_NAME);
+                break;
+            case e300_eeprom_manager::UNKNOWN:
+            default:
+                UHD_MSG(warning) << "Unknown motherboard type, loading e300 image."
                                      << std::endl;
-                    fpga_image = find_image_path(E300_FPGA_FILE_NAME);
-                    break;
-                }
-                common::load_fpga_image(fpga_image);
+                fpga_image = device_addr.cast<std::string>("fpga",
+                    find_image_path(E300_FPGA_FILE_NAME));
+                _idle_image = find_image_path(E300_FPGA_IDLE_FILE_NAME);
+                break;
             }
+            common::load_fpga_image(fpga_image);
         }
     }
 
@@ -578,6 +582,9 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     UHD_MSG(status) << "Initializing time to the internal GPSDO" << std::endl;
     const time_t tp = time_t(_sensor_manager->get_sensor("gps_time").to_int()+1);
     _tree->access<time_spec_t>(mb_path / "time" / "pps").set(time_spec_t(tp));
+
+    // wait for time to be actually set
+    boost::this_thread::sleep(boost::posix_time::seconds(1));
 }
 
 boost::uint8_t e300_impl::_get_internal_gpio(
@@ -618,7 +625,8 @@ uhd::sensor_value_t e300_impl::_get_fe_pll_lock(const bool is_tx)
 
 e300_impl::~e300_impl(void)
 {
-    /* NOP */
+    if (_xport_path == AXI and not _do_not_reload)
+        common::load_fpga_image(_idle_image);
 }
 
 void e300_impl::_enforce_tick_rate_limits(
@@ -1050,6 +1058,7 @@ void e300_impl::_setup_radio(const size_t dspno)
         _tree->create<meta_range_t>(rf_fe_path / "bandwidth" / "range")
             .publish(boost::bind(&ad9361_ctrl::get_bw_filter_range, key));
         _tree->create<double>(rf_fe_path / "freq" / "value")
+            .publish(boost::bind(&ad9361_ctrl::get_freq, _codec_ctrl, key))
             .coerce(boost::bind(&ad9361_ctrl::tune, _codec_ctrl, key, _1))
             .subscribe(boost::bind(&e300_impl::_update_fe_lo_freq, this, key, _1))
             .set(e300::DEFAULT_FE_FREQ);
